pro mdi_write_genxcat, pattern=pattern, clean=clean
;+
;   Name: mdi_write_genxcat
;
;   Purpose: map mdi files (from SOI WWW requests) -> a time based catalog
;
;   Input Parameters:
;      NONE
;
;   Keyword Paramters:
;      pattern - directory file pattern to match
;      clean   - if set, remove all mdi*genx in catalog directory (!)
;                prior to writing
;  
;   History:
;      Circa 15-Nov-1998 - S.L.Freeland
;       2-feb-1999 - S.L.Freeland - a little documentation
;
;   Restrictions:
;      $MDI_MAGS - points to top of mdi data tree  
;  
;   Side Effects:
;      Writes catalog files (genx format) in $MDI_MAGS/mdi_genxcat  
;
;   Assumptions - data files are from a Stanford MDI data request 
;-

if get_logenv('MDI_MAGS') eq '' then begin
     box_message,'Need to define location of $MDI_MAGS , returning...'
     return
endif     


if not keyword_set(pattern) then pattern='fd_M_1024*'
dirs=file_list('$MDI_MAGS',pattern,/cd)

fddirs=strsplit(dirs,'/',/last,/tail)
catdir=concat_dir('$MDI_MAGS','mdi_genxcat')
if not file_exist(catdir) then begin
  box_message,'Directory ' + catdir + ' does not exist, creating it..'
  spawn,['mkdir','-p',catdir],/noshell
endif  

for i=0,n_elements(dirs)-1 do begin
   box_message,'Processing:>> ' + fddirs(i)
   files=file_list(dirs(i),'*.fits',/cd)
   flen=strlen(files)
   imgfiles=files(where(flen eq min(flen)))
   delvarx,mdiind,newind
   rd_mdi, imgfiles, mdiindex
   break_file,imgfiles,ll,pp,ff,ee,vv
   newind=add_tag(mdiindex,'','FILENAME')
   newind.filename='$MDI_MAGS/'+fddirs(i)+'/'+ff+ee+vv
   substr=str_subset(newind,'time,day,filename,naxis1, naxis2, cdelt1,cdelt2,crpix1,crpix2')
   if n_elements(outind) eq 0 then outind=substr else $
       outind=concat_struct(outind,substr)
   fmt_timer,outind
endfor

fmt_timer, outind, firstt, lastt
tgrid=timegrid(firstt, timegrid(lastt,day=2,/date_only,/yohkoh),$
	       /day,/date_only,/yohkoh)

if keyword_set(clean) then begin
  box_message,'Cleaning up old catalogs..'
  files=file_list(catdir,'mdi*genx',/cd)
  file_delete,files
endif  

for i=0,n_elements(tgrid)-2 do begin
  ss=sel_timrange(outind,tgrid(i),tgrid(i+1),/between)
  if ss(0) ne -1 then begin
      fmt_timer,outind(ss)
      write_genxcat,outind(ss),topdir=catdir, prefix='mdifd_', $
         /nelem,/day_round
   endif
endfor

stop
return

end

